/*
    Copyright (C) 2003 KSVG Team
    This file is part of the KDE project

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
*/

#include <qobject.h>

#include <kdebug.h>
#include <kstaticdeleter.h>

#include "SVGDocument.h"
#include "SVGElementImpl.h"
#include "SVGDocumentImpl.h"
#include "SVGDocumentFactory.h"

using namespace KSVG;

namespace KSVG
{
	class SVGDocumentFactory::Private
	{
	public:
		Private() : m_doc(0) { }
		~Private() { delete m_doc; }
	
		void setup(bool bFit) { m_doc = new SVGDocumentImpl(bFit); }
		SVGDocumentImpl *doc() const { return m_doc; }

	private:
		SVGDocumentImpl *m_doc;
	};
};

static KStaticDeleter<SVGDocumentFactory> s_deleter;
static SVGDocumentFactory *s_factory = 0;

SVGDocumentFactory::SVGDocumentFactory() : m_d(new Private())
{
}

SVGDocumentFactory::~SVGDocumentFactory()
{
}

SVGDocumentFactory *SVGDocumentFactory::self()
{
	if(!s_factory)
		s_deleter.setObject(s_factory, new SVGDocumentFactory());
	return s_factory;
}

SVGDocument *SVGDocumentFactory::requestDocument(const KURL &url, QObject *notifyObject, const char *notifySlot) const
{
	SVGDocumentImpl *impl = requestDocumentImpl(false);
	QObject::connect(impl, SIGNAL(finishedParsing(bool, const QString &)), notifyObject, notifySlot);
			
	bool ret = impl->open(url);
	if(!ret)
	{
		kdDebug() << k_funcinfo << " URL is invalid. Couldn't open! Returning 0!" << endl;
		return 0;
	}
		
	return new SVGDocument(impl);
}

SVGDocumentImpl *SVGDocumentFactory::requestDocumentImpl(bool bFit) const
{
	if(!m_d->doc())
		m_d->setup(bFit);

	SVGDocumentImpl *impl = m_d->doc();
	impl->ref();
		
	return impl;
}

// vim:ts=4:noet
